/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for instances in OCI, your private data center, or 3rd-party clouds.
For more information, see [Overview of OS Management Hub](https://docs.oracle.com/iaas/osmh/doc/overview.htm).

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2025, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Represents a specific version of a registration profile.
 */
export interface ProfileVersion {
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the registration profile.
     */
    "id": string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment that contains the registration profile.
     */
    "compartmentId": string;
    /**
     * A user-friendly name for the profile.
     */
    "displayName": string;
    /**
     * The description of the registration profile.
     */
    "description"?: string;
    /**
     * The [OCID](https://docs.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the management station to associate with an
     * instance once registered. Management stations are only used with non-OCI instances.
     *
     */
    "managementStationId"?: string;
    /**
     * The list of software sources that the registration profile will use.
     */
    "softwareSources"?: Array<model.SoftwareSourceDetails>;
    "managedInstanceGroup"?: model.ManagedInstanceGroupDetails;
    "lifecycleEnvironment"?: model.LifecycleEnvironmentDetails;
    "lifecycleStage"?: model.LifecycleStageDetails;
    /**
     * The type of profile.
     */
    "profileType"?: model.ProfileType;
    /**
     * The vendor of the operating system for the instance.
     */
    "vendorName": model.VendorName;
    /**
     * The operating system family.
     */
    "osFamily": model.OsFamily;
    /**
     * The architecture type.
     */
    "archType": model.ArchType;
    /**
     * The time the registration profile was created (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     */
    "timeCreated"?: Date;
    /**
     * The time the registration profile was last modified (in [RFC 3339](https://tools.ietf.org/rfc/rfc3339) format).
     */
    "timeModified"?: Date;
    /**
     * The version of the profile.
     */
    "profileVersion"?: string;
    /**
     * The current state of the registration profile.
     */
    "lifecycleState"?: string;
    /**
     * The type of instance to register.
     */
    "registrationType"?: ProfileVersion.RegistrationType;
    /**
     * Indicates if the profile is set as the default. There is exactly one default profile for a specified architecture, OS family, registration type, and vendor. When registering an instance with the corresonding characteristics, the default profile is used, unless another profile is specified.
     *
     */
    "isDefaultProfile"?: boolean;
    /**
     * Indicates if the profile was created by the service. OS Management Hub provides a limited set of standardized profiles that can be used to register Autonomous Linux or Windows instances.
     *
     */
    "isServiceProvidedProfile"?: boolean;
}
export declare namespace ProfileVersion {
    enum RegistrationType {
        OciLinux = "OCI_LINUX",
        NonOciLinux = "NON_OCI_LINUX",
        OciWindows = "OCI_WINDOWS",
        AutonomousLinux = "AUTONOMOUS_LINUX",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ProfileVersion): object;
    function getDeserializedJsonObj(obj: ProfileVersion): object;
}
